



if not exist %LIBRARY_BIN%\\xwren.exe (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_PREFIX%\\share\\jupyter\\kernels\\xwren\\kernel.json (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\\xeus-wren\\xinterpreter.hpp (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\cmake\\xeus-wren\\xeus-wrenConfig.cmake (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\cmake\\xeus-wren\\xeus-wrenConfigVersion.cmake (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\share\\jupyter\\kernels\\xwren\\kernel.json (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
